#######################################################################
#
# lmsensor component
#
# loads chip modules in /etc/rc.d/rc.local
#
# Hugo Cacote <Hugo.Cacote@cern.ch>
# Version 1.1.24 : 01/04/05 10:11
#
# For license conditions see http://www.eu-datagrid.org/license.html
#
#######################################################################

package NCM::Component::lmsensors;
#
# a few standard statements, mandatory for all components
#
use strict;
use NCM::Component;
use EDG::WP4::CCM::Resource;
use vars qw(@ISA $EC);
@ISA = qw(NCM::Component);
$EC=LC::Exception::Context->new->will_store_all;

use NCM::Check;
use LC::Process qw(run);
use LC::File qw(copy file_contents);


########################################################################
sub Configure {
########################################################################
  my ( $self,$config ) = @_;
 
  unless (-x '/usr/bin/sensors') {
   	$self->error('/usr/bin/sensors not found');
   	return;
  }


  my $moduleEl  = $config->getElement( '/software/components/lmsensors/modules' ) ;
  my @moduleList= $moduleEl->getList();
  
  foreach my $module ( 0 .. $#moduleList ) {
	
        my $chipModuleName = $moduleList[$module]->getValue(); 
	
	#load modules in memory 
 	unless (LC::Process::run('/sbin/modprobe '. $chipModuleName)) {
    		$self->error('problem with "/sbin/modprobe $chipModuleName" command');
    		return;
  	}
  }
}


########################################################################
sub Unconfigure {
########################################################################
  my ( $self,$config ) = @_;

  my $moduleEl = $config->getElement( '/software/components/lmsensors/modules' ) ;
  my @moduleList = $moduleEl->getList();
   	 
  foreach my $module ( 0 .. $#moduleList ) {

       my $chipModuleName = $moduleList[$module]->getValue();
       # unload modules from memory 		
       unless (LC::Process::run('/sbin/rmmod '.$chipModuleName)) {
        	$self->error('problem with "/sbin/rmmod $chipModuleName" command');
	       return;
  	}      
  }
  
  # some extra modules are loaded in memory and need to be unloaded
  my @extraModuleList=('i2c-proc','i2c-core');

  # unloading the extra modules
  foreach my $module ( 0 .. $#extraModuleList ) {	
        unless (LC::Process::run('/sbin/rmmod '.$extraModuleList[$module])) {
       	   $self->error('problem with "/sbin/rmmod $extraModuleList[$module]" command');
           return;
        }  
  }     
}
1; # required for Perl modules
